Titanium.include("Constants.js");

var languages = [ { name: "Føroyskt", sufix: "fo", icon: "faroe.png"}, { name: "English", sufix: "en", icon: "england.png"}, { name: "Dansk", sufix: "da", icon: "dansk.png"}];
var language;
var clickTransform = Ti.UI.create2DMatrix();
clickTransform = clickTransform.scale(0.9, 0.9);

var clickAnimation = Titanium.UI.createAnimation();
clickAnimation.transform = clickTransform;
clickAnimation.duration = 50;
clickAnimation.autoreverse = true;

var clickAnimation_ = Titanium.UI.createAnimation();
clickAnimation_.duration = 50;

//CLASS MainWindow
function MainWindow (title) {
	//calc the density ratio, default dpi is 160
	var ratio = (Titanium.Platform.displayCaps.dpi/160);
	Titanium.API.info("Device display density: " + Titanium.Platform.displayCaps.dpi);
	Titanium.API.info("Scale ratio: " + ratio);
	
    this.win = Titanium.UI.createWindow({
		backgroundColor: '#fff',
		backgroundImage: "images/bkg.png",
		title: title,
		exitOnClose: true,
		orientationModes: [ Titanium.UI.PORTRAIT ]
	});	

	this.btLanguage = Titanium.UI.createButton({
		backgroundImage: "images/faroe.png",
	    top: (Titanium.Platform.displayCaps.platformHeight - 60*ratio),
		left: (Titanium.Platform.displayCaps.platformWidth - 100*ratio),
	    height: 50*ratio,
		width: 80*ratio,
		borderWidth: 1
	});
	this.btRefresh = Titanium.UI.createButton({
		backgroundImage: "images/refresh.png",
	    top: (Titanium.Platform.displayCaps.platformHeight - 61*ratio),
		left: 20*ratio,
	    height: 48*ratio,
		width: 48*ratio
	});
	if(Titanium.Platform.name == "android") {
		this.btLanguage.top -= 12*ratio;
		this.btRefresh.top -= 12*ratio;
	}
	this.win.add(this.btRefresh);
	this.btRefresh.addEventListener("touchstart", this.animateButton);
	this.btRefresh.addEventListener("touchend", this.restoreButton);
	this.btRefresh.addEventListener("click", this.clearCache);
	
	this.win.add(this.btLanguage);
	this.btLanguage.addEventListener("touchstart", this.animateButton);
	this.btLanguage.addEventListener("touchend", this.restoreButton);

	var bt_w = ratio*317;
	var bt_h = ratio*110;
	Titanium.API.info(bt_w);
	
	this.btIncoming = Titanium.UI.createButton({
	    top: 5*ratio,
	    width: bt_w,
	    height: bt_h,
	    borderWidth: 1,
		color: "#EEEEEE",
	    borderColor: "#A66",
	    borderRadius: 2
	});
	this.addButtonEvents(this.btIncoming);
	this.win.add(this.btIncoming);
	
	this.btHotel = Titanium.UI.createButton({
	    top: 124*ratio,
	    width: bt_w,
	    height: bt_h,
	    borderWidth: 1,
	    borderColor: "#A66",
	    borderRadius: 2
	});
	this.addButtonEvents(this.btHotel);
	this.win.add(this.btHotel);

	this.btRental = Titanium.UI.createButton({
	    top: 243*ratio,
	    width: bt_w,
	    height: bt_h,
	    borderWidth: 1,
	    borderColor: "#A66",
	    borderRadius: 2
	});
	this.addButtonEvents(this.btRental);
	this.win.add(this.btRental);
	
	this.win.open({fullscreen:true});
	this.setLanguage(this);
}

//static vars

//methods
MainWindow.prototype.toString = function() {
	return "Abix 62n MainWindow";
};

MainWindow.prototype.animateButton = function(e) {
	e.source.animate(clickAnimation);
};
	
MainWindow.prototype.restoreButton = function(e) {	
	e.source.animate(clickAnimation_); 
};

MainWindow.prototype.addButtonEvents = function(btn) {
	btn.addEventListener("touchstart", this.animateButton);
	btn.addEventListener("touchend", this.restoreButton);
	btn.addEventListener("click", this.onButtonClick);
};

MainWindow.prototype.onButtonClick = function(e) {
	if (!Titanium.Network.online) {
		alert("This application requires network access.\nEnable mobile netowrk or Wi-Fi to proceed");
	} else {
		var win = Titanium.UI.createWindow({
			url: "Window62n.js",
			header: e.source.axTitle,
			menu: e.source.axMenu,
			backgroundColor: '#eeeeee',
			title: "Go2Faroes"
		});
		win.open({fullscreen:true, modal: true });
	}
};

MainWindow.prototype.clearCache = function(e) {
	var files = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory).getDirectoryListing();
	var n = 0;
	for(var i=0;i<files.length;i++) {
		var x = files[i].indexOf(".62n");
		if (x > -1) {
			Titanium.API.info("deleting: " + files[i]);
			Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory, files[i]).deleteFile();
			n++;
		}
	}

};

MainWindow.prototype.setLanguage = function(that) {
	var f = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory,'data.dat');
	var lang_settings = "";
	if(f.size >= 6) {
		settings = String(f.read());
	}

    var dlg = Titanium.UI.createOptionDialog({
        title: '',
		cancel: -1
    });

	if(Titanium.Platform.name == "android") {
		dlg.options = [ languages[0].name, languages[1].name, languages[2].name ];
	} else {
		dlg.options = [ languages[0].name, languages[1].name, languages[2].name, "Cancel"];
		dlg.cancel = 3;
	}
    dlg.addEventListener("click", function(e){
		f = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory,'data.dat');
		f.write("lang:" + e.index);
		Titanium.App.language = e.index;
        language = languages[e.index];
        that.updateLanguage();
    });
	this.btLanguage.addEventListener("click", function(e) {
		dlg.show();
	});
	if(f.size < 6) {
		Titanium.API.info(dlg.options.length);
		dlg.show();
	}
	else {
		var i = settings.indexOf(":");
		language = languages[settings.substring(i+1)];
		this.updateLanguage();
	}
};

MainWindow.prototype.updateLanguage = function(){
	Titanium.API.info(language);
	Titanium.App.Properties.setString("language", language.sufix);
    this.btLanguage.backgroundImage = "images/" + language.icon;
    this.btIncoming.backgroundImage = "images/incoming_" + language.sufix + ".png";
    this.btHotel.backgroundImage = "images/hotel_" + language.sufix + ".png";
    this.btRental.backgroundImage = "images/rental_" + language.sufix + ".png";
    if (language.sufix == "fo") {
		this.btIncoming.axTitle = FO_INCOMING;
		this.btIncoming.axMenu = FO_INCOMING_MENU;
		this.btHotel.axTitle = FO_HOTEL;
		this.btHotel.axMenu = FO_HOTEL_MENU;
		this.btRental.axTitle = FO_RENTAL;
		this.btRental.axMenu = FO_RENTAL_MENU;
	}
	else {
		if (language.sufix == "da") {
			this.btIncoming.axTitle = DA_INCOMING;
			this.btIncoming.axMenu = DA_INCOMING_MENU;
			this.btHotel.axTitle = DA_HOTEL;
			this.btHotel.axMenu = DA_HOTEL_MENU;
			this.btRental.axTitle = DA_RENTAL;
			this.btRental.axMenu = DA_RENTAL_MENU;
		}
		else {
			this.btIncoming.axTitle = EN_INCOMING;
			this.btIncoming.axMenu = EN_INCOMING_MENU;
			this.btHotel.axTitle = EN_HOTEL;
			this.btHotel.axMenu = EN_HOTEL_MENU;
			this.btRental.axTitle = EN_RENTAL;
			this.btRental.axMenu = EN_RENTAL_MENU;
		}
	}
};
//~CLASS MainWindow
